@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -8,7 +8,7 @@
 
 from qiime2.plugin import (Plugin, Int, Float, Range, Metadata, Str, Bool,
                            Choices, MetadataColumn, Categorical, List,
-                           Citations, TypeMatch)
+                           Citations, TypeMatch, TypeMap)
 
 import q2_feature_table
 from q2_types.feature_table import (
@@ -174,14 +174,25 @@ plugin.methods.register_function(
                 "to define the mapping of IDs to a group."
 )
 
+i_table, p_overlap_method, o_table = TypeMap({
+    (FeatureTable[Frequency],
+     Str % Choices(sorted(q2_feature_table.overlap_methods()))):
+    FeatureTable[Frequency],
+    (FeatureTable[RelativeFrequency],
+     # We don't want to allow summing of RelativeFrequency tables, so remove
+     # that option from the overlap methods
+     Str % Choices(sorted(q2_feature_table.overlap_methods() - {'sum'}))):
+    FeatureTable[RelativeFrequency]
+})
+
 plugin.methods.register_function(
     function=q2_feature_table.merge,
-    inputs={'tables': List[FeatureTable[Frequency]]},
+    inputs={'tables': List[i_table]},
     parameters={
-        'overlap_method': Str % Choices(q2_feature_table.overlap_methods()),
+        'overlap_method': p_overlap_method
     },
     outputs=[
-        ('merged_table', FeatureTable[Frequency])],
+        ('merged_table', o_table)],
     input_descriptions={
         'tables': 'The collection of feature tables to be merged.',
     },
@@ -288,7 +299,8 @@ plugin.methods.register_function(
                 'max_features': Int,
                 'metadata': Metadata,
                 'where': Str,
-                'exclude_ids': Bool},
+                'exclude_ids': Bool,
+                'filter_empty_features': Bool},
     outputs=[('filtered_table', FeatureTable[T1])],
     input_descriptions={
         'table': 'The feature table from which samples should be filtered.'
@@ -315,7 +327,9 @@ plugin.methods.register_function(
                  'also in the feature table will be retained.',
         'exclude_ids': 'If true, the samples selected by `metadata` or '
                        '`where` parameters will be excluded from the filtered '
-                       'table instead of being retained.'
+                       'table instead of being retained.',
+        'filter_empty_features': 'If true, features which are not present in '
+                                 'any retained samples are dropped.',
     },
     output_descriptions={
         'filtered_table': 'The resulting feature table filtered by sample.'
@@ -366,7 +380,8 @@ plugin.methods.register_function(
                 'max_samples': Int,
                 'metadata': Metadata,
                 'where': Str,
-                'exclude_ids': Bool},
+                'exclude_ids': Bool,
+                'filter_empty_samples': Bool},
     outputs=[('filtered_table', FeatureTable[Frequency])],
     input_descriptions={
         'table': 'The feature table from which features should be filtered.'
@@ -393,7 +408,9 @@ plugin.methods.register_function(
                  'also in the feature table will be retained.',
         'exclude_ids': 'If true, the features selected by `metadata` or '
                        '`where` parameters will be excluded from the filtered '
-                       'table instead of being retained.'
+                       'table instead of being retained.',
+        'filter_empty_samples': 'If true, drop any samples where none of the '
+                                'retained features are present.',
     },
     output_descriptions={
         'filtered_table': 'The resulting feature table filtered by feature.'
